@@ -885,52 +885,42 @@ class BaseExperiment:
                             
                             if best_val is None:
                                 best_val = val_score
-                                best_path = file
                                 model_type = logs['model_type']
                                 best_model_metadata = metadata
                                 best_version = version
                             elif mode == "max" and val_score > best_val:
                                 best_val = val_score
-                                best_path = file
                                 model_type = logs['model_type']
                                 best_model_metadata = metadata
                                 best_version = version
                             elif mode == "min" and val_score < best_val:
                                 best_val = val_score
-                                best_path = file
                                 model_type = logs['model_type']
                                 best_model_metadata = metadata
                                 best_version = version
                             info = {val_metric : best_val}
         if not fetch_only_dir:
             ckpt_path = f'{self.log_path}/checkpoints/{model_type}/{best_model_metadata}/{best_version}' 
-            ckpt_name = str(best_path).replace(".json", "")
             extension_candidates = [".ckpt", ".sav"]
-            for extension_type in extension_candidates:
-                ckpt = ckpt_name + extension_type
-                print(ckpt)
-                if os.path.exists(ckpt):
-                    ckpt_dir = ckpt
-                    ckpt_extension_type = extension_type
-            if ckpt_extension_type not in extension_candidates:
-                raise ValueError(f"Wrong file extension {ckpt_extension_type} for the checkpoint. It should be in {extension_candidates}")
-            if ckpt_extension_type == ".sav":
-                best_ckpt = pickle.load(open(ckpt_dir, 'rb'))
-            elif BaseNet in inspect.getmro(model_type) or ConvNet in inspect.getmro(model_type):
-                best_ckpt = eval(model_type).load_from_checkpoint(dims=self.dims, n_classes=self.n_classes, checkpoint_path=ckpt_dir)
-            elif pl.LightningModule in inspect.getmro(model_type):
-                best_ckpt = eval(model_type).load_from_checkpoint(checkpoint_path=ckpt_dir)
-            else:
-                raise AssertionError
-            return best_ckpt, info
+            for ckpt_dir in os.listdir(ckpt_path):
+                ckpt_extension_type = str(ckpt_dir).split('.')[-1]
+                if ckpt_extension_type not in extension_candidates:
+                    raise ValueError(f"Wrong file extension {ckpt_extension_type} for the checkpoint. It should be in {extension_candidates}")
+                if ckpt_extension_type == ".sav":
+                    best_ckpt = pickle.load(open(ckpt_dir, 'rb'))
+                elif BaseNet in inspect.getmro(model_type) or ConvNet in inspect.getmro(model_type):
+                    best_ckpt = eval(model_type).load_from_checkpoint(dims=self.dims, n_classes=self.n_classes, checkpoint_path=ckpt_dir)
+                elif pl.LightningModule in inspect.getmro(model_type):
+                    best_ckpt = eval(model_type).load_from_checkpoint(checkpoint_path=ckpt_dir)
+                else:
+                    raise AssertionError
+                return best_ckpt, info
         else:
             ckpt_path = f'{self.log_path}/checkpoints/{model_type}/{best_model_metadata}/{best_version}'
-            ckpt_name = str(best_path).replace(".json", "")
             extension_candidates = [".ckpt", ".sav"]
-            for extension_type in extension_candidates:
-                ckpt = ckpt_name + extension_type
-                if os.path.exists(ckpt):
-                    ckpt_dir = ckpt
+            for ckpt_dir in os.listdir(ckpt_path):
+                if os.path.exists(ckpt_dir):
+                    ckpt_dir = ckpt_dir
             return str(ckpt_dir), info
         
     
